@@ -1,26 +1,12 @@
 /*
-    Copyright 2013 Jan Grulich <jgrulich@redhat.com>
-    Copyright 2013 Daniel Nicoletti <dantti12@gmail.com>
+    SPDX-FileCopyrightText: 2013 Jan Grulich <jgrulich@redhat.com>
+    SPDX-FileCopyrightText: 2013 Daniel Nicoletti <dantti12@gmail.com>
 
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Lesser General Public
-    License as published by the Free Software Foundation; either
-    version 2.1 of the License, or (at your option) version 3, or any
-    later version accepted by the membership of KDE e.V. (or its
-    successor approved by the membership of KDE e.V.), which shall
-    act as a proxy defined in Section 6 of version 3 of the license.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public
-    License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 */
 
-#include "infinibanddevice_p.h"
 #include "device_p.h"
+#include "infinibanddevice_p.h"
 #include "manager.h"
 
 NetworkManager::InfinibandDevicePrivate::InfinibandDevicePrivate(const QString &path, InfinibandDevice *q)
@@ -32,8 +18,6 @@ NetworkManager::InfinibandDevicePrivate::InfinibandDevicePrivate(const QString &
 #endif
     , carrier(false)
 {
-    carrier = iface.carrier();
-    hwAddress = iface.hwAddress();
 }
 
 NetworkManager::InfinibandDevice::~InfinibandDevice()
@@ -44,7 +28,11 @@ NetworkManager::InfinibandDevice::InfinibandDevice(const QString &path, QObject
     : Device(*new InfinibandDevicePrivate(path, this), parent)
 {
     Q_D(InfinibandDevice);
-    connect(&d->iface, &OrgFreedesktopNetworkManagerDeviceInfinibandInterface::PropertiesChanged, d, &InfinibandDevicePrivate::propertiesChanged);
+
+    QVariantMap initialProperties = NetworkManagerPrivate::retrieveInitialProperties(d->iface.staticInterfaceName(), path);
+    if (!initialProperties.isEmpty()) {
+        d->propertiesChanged(initialProperties);
+    }
 }
 
 NetworkManager::InfinibandDevicePrivate::~InfinibandDevicePrivate()
